@@ -27,18 +27,20 @@
 #' \code{expss_enable_value_labels_support_extreme()} and
 #' \code{expss_disable_value_labels_support()}.}
 #' \item{\code{expss.output} }{ By default tables are printed in the console. 
-#' You can change this behavior by setting this option. There are four possible
-#' values: \code{'rnotebook'}, \code{'viewer'}, \code{'commented'} or 
-#' \code{'raw'}. First option is useful when you run your code in the R Notebook
+#' You can change this behavior by setting this option. There are five possible
+#' values: \code{'rnotebook'}, \code{'viewer'}, \code{'commented'},  
+#' \code{'raw'} or \code{'huxtable'}. First option is useful when you run your code in the R Notebook
 #' - output will be rendered to nice HTML. The second option will render tables 
 #' to RStudio viewer. \code{knitr} is supported automatically via 
 #' \code{knit_print} method. \code{'commented'} prints default output to the 
 #' console with comment symbol (\code{#}) at the beginning of the each line.
 #' With comment symbol you can easily copy and paste your output into the
 #' script. Option \code{raw} disables any formatting and all tables are printed
-#' as data.frames. Shortcuts for options: \code{expss_output_default()}, 
+#' as data.frames. Option \code{huxtable} print output via the huxtable library.
+#' Shortcuts for options: \code{expss_output_default()}, 
 #' \code{expss_output_raw()}, \code{expss_output_viewer()},
-#' \code{expss_output_commented()} and \code{expss_output_rnotebook()}.}
+#' \code{expss_output_commented()}, \code{expss_output_rnotebook()} and  
+#' \code{expss_output_huxtable()}.}
 #' \item{\code{expss_fix_encoding_on}/\code{expss_fix_encoding_off} }{ If you
 #' expreience problems with character encoding in RStudio Viewer/RNotebooks under Windows
 #' try \code{expss_fix_encoding_on()}. In some cases, it can help.}
@@ -46,7 +48,8 @@
 #' 
 #' @param digits integer. Number of digits after decimal point. \code{NULL} is
 #'   default and means 1 digit. \code{NA} means no rounding.
-#' 
+#' @param ... list of parameters for \code{huxtable::set_default_properties}. See \link[huxtable]{set_default_properties}.
+#' @param label character vector of length 5. Default labels for \link{fre}.
 #' @name expss.options
 #' @examples 
 #' 
@@ -139,6 +142,24 @@ expss_output_rnotebook = function(){
     options(expss.output = "rnotebook")
 }
 
+
+#' @rdname expss.options
+#' @export
+expss_output_huxtable = function(...){
+    requireNamespace("huxtable", quietly = TRUE) ||
+        stop("'expss_output_huxtable': 'huxtable' package is required for this function. Please, install it with 'install.packages('huxtable')'.")
+    huxtable::set_default_properties(left_border =  1)
+    huxtable::set_default_properties(right_border =  1)
+    huxtable::set_default_properties(top_border =  1)
+    huxtable::set_default_properties(bottom_border =  1)
+    huxtable::set_default_properties(left_border_color =  "black")
+    huxtable::set_default_properties(right_border_color =  "black")
+    huxtable::set_default_properties(top_border_color =  "black")
+    huxtable::set_default_properties(bottom_border_color =  "black")
+    if(length(list(...))>0) huxtable::set_default_properties(...)
+    options(expss.output = "huxtable")
+}
+
 #' @rdname expss.options
 #' @export
 expss_fix_encoding_on = function(){
@@ -149,4 +170,10 @@ expss_fix_encoding_on = function(){
 #' @export
 expss_fix_encoding_off = function(){
     options(expss.fix_encoding = NULL)
-}
\ No newline at end of file
+}
+
+#' @rdname expss.options
+#' @export
+expss_fre_stat_lab = function(label = c("Count", "Valid percent", "Percent", "Responses, %", "Cumulative responses, %")){
+    options(expss.fre_stat_lab = label)
+}
