@@ -288,18 +288,46 @@ matrix_to_cgroup = function(header){
 #' }
 #' @rdname htmlTable.etable
 knit_print.etable = function(x, digits = get_expss_digits(), escape.html = FALSE, ...){
-    knitr::knit_print(htmlTable.etable(x, digits = digits, 
-                                       escape.html = escape.html,
+    
+    # Get type of document
+    type = knitr::is_html_output()
+    
+    
+    # Check if huxtable is available
+    hux_available = requireNamespace("huxtable", quietly = TRUE)
+    hux_output = identical(getOption("expss.output"), "huxtable")
+    
+    # For html or markdown use htmlTable, for latex and docx huxtable (if available)
+    if((type || !hux_available) & !hux_output) {
+        knitr::knit_print(htmlTable.etable(x, digits = digits, 
+                                    escape.html = escape.html,
                                        ..., row_groups = TRUE))
+    } else {
+        knitr::knit_print(huxtable::as_hux(x), ...)
+    }
 }
 
 
 #' @rdname htmlTable.etable
 knit_print.with_caption = function(x, digits = get_expss_digits(), escape.html = FALSE, ...){
-    knitr::knit_print(htmlTable.with_caption(x, digits = digits, 
-                                             escape.html = escape.html,
-                                             ..., row_groups = TRUE)
-    )
+
+    # Get type of document
+    type = knitr::is_html_output()
+    
+    
+    # Check if huxtable is available
+    hux_available = requireNamespace("huxtable", quietly = TRUE)
+    hux_output = identical(getOption("expss.output"), "huxtable")
+    
+    # For html or markdown use htmlTable, for latex and docx huxtable (if available)
+    if((type || !hux_available) & !hux_output) {
+        knitr::knit_print(htmlTable.with_caption(x, digits = digits, 
+                                           escape.html = escape.html,
+                                           ..., row_groups = TRUE))
+    } else {
+        knitr::knit_print(huxtable::as_hux(x), ...)
+    }
+    
 }
 
 
