@@ -1,4 +1,5 @@
 context("%into%_2")
+suppressWarnings(RNGversion("3.5.0"))
 
 data(iris)
 
@@ -21,13 +22,13 @@ w_test$good = as.character(w_test$Species)
 ###########
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 
-ir_test[,subst("v`1:4`r")] = ir[,subst("v`1:4`")]
+ir_test[,text_expand("v{1:4}r")] = ir[,text_expand("v{1:4}")]
 
 ir = modify(ir, {
-    v1 %to% v4 %into% subst("v`1:4`r")
+    v1 %to% v4 %into% text_expand("v{1:4}r")
     
 }
 )
@@ -37,10 +38,10 @@ expect_identical(ir, ir_test)
 ###########
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 
-ir_test[,subst("vr`1:4`")] = ir[,subst("v`1:4`")]
+ir_test[,text_expand("vr{1:4}")] = ir[,text_expand("v{1:4}")]
 
 name1  = "vr1"
 name2  = "vr4"
@@ -73,10 +74,10 @@ expect_identical(ir_res, ir_test)
 
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 
-ir_test[,subst("vr`1:4`")] = ir[,subst("v`1:4`")]
+ir_test[,text_expand("vr{1:4}")] = ir[,text_expand("v{1:4}")]
 
 ir = modify(ir, {
     v1 %to% v4 %into% (vr1 %to% vr4)
@@ -90,14 +91,14 @@ expect_identical(ir, ir_test)
 
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 
-ir_test[,subst("v`1:4`r")] = NA
-ir_test[ir_test$Species == "setosa",subst("v`1:4`r")] = ir[ir_test$Species == "setosa",subst("v`1:4`")]
+ir_test[,text_expand("v{1:4}r")] = NA
+ir_test[ir_test$Species == "setosa",text_expand("v{1:4}r")] = ir[ir_test$Species == "setosa",text_expand("v{1:4}")]
 
 ir = modify_if(ir, Species == "setosa", {
-    v1 %to% v4 %into% subst("v`1:4`r")
+    v1 %to% v4 %into% text_expand("v{1:4}r")
     
     }
 )
@@ -110,15 +111,15 @@ expect_identical(ir, ir_test)
 ###########
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
-ir_test[,subst("v`1`r")] = 1L 
-ir_test[,subst("v`2`r")] = 2L
-ir_test[,subst("v`3`r")] = 3L
-ir_test[,subst("v`4`r")] = 4L
+ir_test[,text_expand("v{1}r")] = 1L 
+ir_test[,text_expand("v{2}r")] = 2L
+ir_test[,text_expand("v{3}r")] = 3L
+ir_test[,text_expand("v{4}r")] = 4L
 
 ir = compute(ir, {
-    t(1:4) %into% subst("v`1:4`r")
+    t(1:4) %into% text_expand("v{1:4}r")
 }
 )
 
@@ -127,14 +128,14 @@ expect_identical(ir, ir_test)
 ###########
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 
-ir_test[,subst("v`1:4`r")] = 1L:150L 
+ir_test[,text_expand("v{1:4}r")] = 1L:150L 
 
 
 ir = compute(ir, {
-    1:150 %into% subst("v`1:4`r")
+    1:150 %into% text_expand("v{1:4}r")
 }
 )
 
@@ -143,13 +144,13 @@ expect_identical(ir, ir_test)
 ###########
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 
 
 expect_error({
 ir = compute(ir, {
-    1:2 %into% subst("v`1:4`r")
+    1:2 %into% text_expand("v{1:4}r")
     
 })
 }
@@ -158,13 +159,13 @@ ir = compute(ir, {
 ###########
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 
 
 expect_error({
     ir = compute(ir, {
-        t(1:2) %into% subst("v`1:4`r")
+        t(1:2) %into% text_expand("v{1:4}r")
         
     }
     )
@@ -176,17 +177,17 @@ expect_error({
 # if(FALSE){
 data(iris)
 ir = iris
-colnames(ir)[1:4] = subst("v`1:4`")
+colnames(ir)[1:4] = text_expand("v{1:4}")
 ir_test = ir
 i = 1:4
 
-ir_test[,subst("v`1`r")] = 1L 
-ir_test[,subst("v`2`r")] = 2L
-ir_test[,subst("v`3`r")] = 3L
-ir_test[,subst("v`4`r")] = 4L
+ir_test[,text_expand("v{1}r")] = 1L 
+ir_test[,text_expand("v{2}r")] = 2L
+ir_test[,text_expand("v{3}r")] = 3L
+ir_test[,text_expand("v{4}r")] = 4L
 i = 1:4
 ir = compute(ir, {
-    t(1:4) %into% subst("v`i`r")
+    t(1:4) %into% text_expand("v{i}r")
     
 }
 )
